@@ -33,6 +33,9 @@
 #	include <config.h>
 #endif
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include "timeloop.h"
 #include <synfig/valuenode.h>
 #include <synfig/valuenodes/valuenode_const.h>
@@ -46,9 +49,11 @@
 
 #endif
 
-using namespace synfig;
 using namespace std;
 using namespace etl;
+using namespace synfig;
+using namespace modules;
+using namespace lyr_std;
 
 /* === M A C R O S ========================================================= */
 
@@ -57,7 +62,7 @@ using namespace etl;
 SYNFIG_LAYER_INIT(Layer_TimeLoop);
 SYNFIG_LAYER_SET_NAME(Layer_TimeLoop,"timeloop");
 SYNFIG_LAYER_SET_LOCAL_NAME(Layer_TimeLoop,N_("Time Loop"));
-SYNFIG_LAYER_SET_CATEGORY(Layer_TimeLoop,N_("Other"));
+SYNFIG_LAYER_SET_CATEGORY(Layer_TimeLoop,N_("Time"));
 SYNFIG_LAYER_SET_VERSION(Layer_TimeLoop,"0.2");
 SYNFIG_LAYER_SET_CVS_ID(Layer_TimeLoop,"$Id$");
 
@@ -241,7 +246,7 @@ Layer_TimeLoop::reset_version()
 }
 
 void
-Layer_TimeLoop::set_time(IndependentContext context, Time t)const
+Layer_TimeLoop::set_time_vfunc(IndependentContext context, Time t)const
 {
 	Time link_time=param_link_time.get(Time());
 	Time local_time=param_local_time.get(Time());
@@ -287,22 +292,3 @@ Layer_TimeLoop::set_time(IndependentContext context, Time t)const
 	}
 	context.set_time(t);
 }
-
-Color
-Layer_TimeLoop::get_color(Context context, const Point &pos)const
-{
-	return context.get_color(pos);
-}
-
-bool
-Layer_TimeLoop::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
-{
-	return context.accelerated_render(surface,quality,renddesc,cb);
-}
-
-
-bool
-Layer_TimeLoop::accelerated_cairorender(Context context,cairo_t *cr, int quality, const RendDesc &renddesc, ProgressCallback *cb)const
-{
-	return context.accelerated_cairorender(cr,quality,renddesc,cb);
-}
