@@ -34,6 +34,9 @@
 #include "halftone2.h"
 #include "halftone.h"
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/string.h>
 #include <synfig/time.h>
 #include <synfig/context.h>
@@ -66,7 +69,7 @@ SYNFIG_LAYER_SET_CVS_ID(Halftone2,"$Id$");
 /* === M E T H O D S ======================================================= */
 
 Halftone2::Halftone2():
-	Layer_Composite(1.0,Color::BLEND_STRAIGHT),
+	Layer_CompositeFork(1.0,Color::BLEND_STRAIGHT),
 	param_color_dark(ValueBase(Color::black())),
 	param_color_light(ValueBase(Color::white()))
 {
@@ -353,4 +356,8 @@ Halftone2::accelerated_cairorender(Context context,cairo_t *cr,int quality, cons
 	return true;
 }
 
+rendering::Task::Handle
+Halftone2::build_rendering_task_vfunc(Context context) const
+	{ return Layer::build_rendering_task_vfunc(context); }
+
 ///
